@@ -44,10 +44,6 @@ void gdaConnection::setCStruct(Gda_Connection *cnc) {
 	_gda_connection = cnc;
 }
 		
-GList* gdaConnection::listProviders() {
-	return gda_connection_list_providers();
-}
-
 void gdaConnection::setProvider(gchar* name) {
 	gda_connection_set_provider(_gda_connection,name);
 }
@@ -78,10 +74,6 @@ gdaErrorList* gdaConnection::getErrors() {
 	return a;
 }
 
-GList* gdaConnection::listDatasources() {
-	return gda_connection_list_datasources(_gda_connection);
-}
-
 gint gdaConnection::beginTransaction() {
 	return gda_connection_begin_transaction(_gda_connection);
 }
