@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-tds-connection.c,v 1.2 2000/11/21 19:57:14 holger Exp $
+ * $Id: gda-tds-connection.c,v 1.3 2000/11/27 17:50:28 rodrigo Exp $
  *
  * GNOME DB Tds Provider
  * Copyright (C) 2000 Holger Thon
@@ -22,6 +22,11 @@
  */
 
 // $Log: gda-tds-connection.c,v $
+// Revision 1.3  2000/11/27 17:50:28  rodrigo
+// 2000-11-27	Rodrigo Moya <rodrigo@gnome-db.org>
+//
+// 	* added modifySchema method to GDA::Connection interface
+//
 // Revision 1.2  2000/11/21 19:57:14  holger
 // 2000-11-21 Holger Thon <holger@gidayu.max.uni-duisburg.de>
 //
@@ -256,6 +261,15 @@ gda_tds_connection_open_schema (Gda_ServerConnection *cnc,
   return NULL;
 }
 
+glong
+gda_tds_connection_modify_schema (Gda_ServerConnection *cnc,
+                                   GDA_Connection_QType t,
+                                   GDA_Connection_Constraint *constraints,
+                                   gint length)
+{
+  return -1;
+}
+
 gint
 gda_tds_connection_start_logging(Gda_ServerConnection *cnc,
                                     const gchar *filename)
